"""
__init__.py of OPC_Connector package
"""
from OPC_Connector.Helpers import Logger, OPCClient


def get_opc_client(server_name: str):
    """
    Get an OPCClient instance based on the server name.

    This function loads the configuration and returns an instance of OPCClient configured for the specified OPC server.
    Each OPC connection is determined by the server name, and the configuration for each connection must be defined in 'config.json'.

    Args:
        server_name (str): The name of the OPC server configuration to load from 'config.json'.

    Returns:
        OPCClient: An instance of OPCClient configured for the specified OPC server.
    """
    # Start the logger if enabled in configuration (config.json)
    Logger.load()

    # Get the OPCClient instance
    opc = OPCClient(server_name)
    return opc
